@@ -3,23 +3,19 @@
  ## it under the terms of the GNU General Public License as published
  ## by the Free Software Foundation; version 2 only.
  ##
- ## This program is distributed in the hope that it will be useful,
+ ## This program is distributed in the hope that it will be useful,  
  ## but WITHOUT ANY WARRANTY; without even the implied warranty of
  ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  ## GNU General Public License for more details.
  ##
-
 from PyQt4 import QtCore, QtGui
 from ui.mainWindow import MainWindow
 
 if __name__ == "__main__":
-    try:
-        import sys
-        app = QtGui.QApplication(sys.argv)
-        ui = MainWindow()
-        ui.showFullScreen() 
-        ui.setWindowTitle('AnselA-Image Darkroom')
-        ui.show()
-        sys.exit(app.exec_())
-    except Exception, e:
-        print e
\ No newline at end of file
+    import sys
+    app = QtGui.QApplication(sys.argv)
+    ui = MainWindow()
+    ui.showFullScreen() 
+    ui.setWindowTitle('AnselA-Image Darkroom')
+    ui.show()
+    sys.exit(app.exec_()) 
