@@ -66,7 +66,12 @@ class ParamValues():
         self.curIm =""
         self.curThumb = ""
         self.origIm = ""
+        self.plistIm = ""
         self.valCurTab=0
         self.ApplyVisible = True #Leave true so Init_ can hide
+        self.imageDir = "/home/user/MyDocs/DCIM/"
+        self.thumbsDir = "/home/user/apps/anselA/.thumbs/"
+        self.cancelPlistToggle = False
+        self.thumbsCount = 0
         
         #if __name__ == '__main__':
