@@ -6,6 +6,7 @@ Module implementing MainWindow GUI, anselA
 
 import os
 import sys
+import glob
 import EXIF
 import math
 import operator
@@ -35,10 +36,12 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
+        self.movie = QtGui.QMovie()
         self.ImageOpen(self.val.curImageLoc)
         self.postSetup()
         self.ImageDisplayRefresh(True)
         self.ShowApply(False)
+
     
     def postSetup(self):
         self.tabStrip.setCurrentIndex(0)
@@ -66,10 +69,10 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         else:
             if (show == True):
                 self.FullScreenToggle(True)
-                self.labWait.setGeometry(QtCore.QRect(0, 0, 800, 441))
+                self.labWait.setGeometry(QtCore.QRect(0, 0, 797, 433))
             else:
                 self.FullScreenToggle(False)
-                self.labWait.setGeometry(QtCore.QRect(0, 0, 0, 441))
+                self.labWait.setGeometry(QtCore.QRect(0, 0, 0, 433))
         self.labWait.repaint()
         self.repaint()
 
@@ -326,8 +329,6 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
         elif  (index==6):
             self.ReturnHistPlots()
-        elif (index==8):
-            self.AnimateTab()
         else:
             self.val.valCurTab = index
         
@@ -381,8 +382,10 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         Open File and poulate class parameters of Image.
         """
-        self.val.curIm = Image.open(filename)
-        
+        self.ToggleThumbWait(True)
+        self.repaint()
+        self.val.curIm= (Image.open(filename))
+
         p = open(filename, "rb")
         tags = EXIF.process_file(p)
         for key in tags.keys():
@@ -397,7 +400,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                     
                 if (newItem !="" and  newItem.startswith("Maker Note") == False  and  newItem.startswith("MakerNote") == False  and  newItem.startswith("EXIF") == False):
                     self.listEXIFData.addItem(newItem)
-                    self.listView
+                    #self.listView
             except Exception, e:
                 continue
                 #print "EXIF Error"
@@ -428,14 +431,16 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         size = (wTh,  hTh )
         self.val.curThumb = im.resize(size, Image.ANTIALIAS)
         self.photo_Thumb.repaint()
+        self.ToggleThumbWait(False)
+        
         
         if LoadOriginal:
-            wTh,  hTh = self.convertImSize(w, h,  800)
-            self.photo_Orig.setGeometry(QtCore.QRect(400-int(wTh/2), 220-int(hTh/2), wTh, hTh))
+            wTh,  hTh = self.convertImSize(w, h,  796)
+            self.photo_Orig.setGeometry(QtCore.QRect(398-int(wTh/2), 216-int(hTh/2), wTh, hTh))
             self.photo_Orig.repaint()
             
-        wTh,  hTh = self.convertImSize(w, h,  800)
-        self.photo.setGeometry(QtCore.QRect(400-int(wTh/2), 220-int(hTh/2), wTh, hTh))
+        wTh,  hTh = self.convertImSize(w, h,  796)
+        self.photo.setGeometry(QtCore.QRect(398-int(wTh/2), 216-int(hTh/2), wTh, hTh))
         self.photo.repaint()
 
         #800, 440
@@ -449,14 +454,94 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         Slot documentation goes here.
         """
-#        if (index == 0):
-#            self.FullScreenToggle(False)
-#        else:
-#            self.FullScreenToggle(True)
+        if (index == 2):
+            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 40, 0, 0))
+            self.populatePhotoList()
+        else:
+            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 40, 790, 440))
 
 #+++++++++++++++++++++++ END of Class    
-    
+    @pyqtSignature("Bool")
+    def populatePhotoList(self, ForceRefresh=False):
+        """
+        Slot documentation goes here.
+        """
+        if self.val.thumbsCount == 0:
+            self.val.thumbsCount =50
+            
+        self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 800, 441))
+        self.val.populatePhotoList = True
+        self.listPhotos.clear()
+        
+        self.repaint()
+        self.tabPhoto.repaint()
+        Tsize = (100, 100)
+        i=0
+        self.labCancel.setText("Loading Photos...")
+        if not os.path.exists (self.val.thumbsDir):
+            os.makedirs (self.val.thumbsDir)
+        
+        files =[]
+        for file in os.listdir(self.val.imageDir):
+            files.append(file)
+            
+        for file in reversed(files):
+            if self.val.populatePhotoList ==True:
 
+                if ((not os.path.exists(self.val.thumbsDir+file)) or ForceRefresh):
+                    try:
+                        im = Image.open(self.val.imageDir+file)
+                        im.thumbnail((Tsize), Image.ANTIALIAS)
+                        #os.remove(self.val.thumbsDir+file)
+                        im.save(self.val.thumbsDir+file)
+                    except:
+                        continue
+                    #                    p = open(self.val.imageDir+file, "rb")
+                    #                    tags = EXIF.process_file(p)
+                    #                    Image.open()
+                    #                    tags.get('JPEGThumbnail')
+                
+                try:
+
+                    self.listPhotos.addItem(file.replace(".jpg", ""))
+                    icon = QtGui.QIcon(self.val.thumbsDir+file)
+                    self.listPhotos.item(i).setIcon(icon)
+                    if i % 5 == 0:
+                        self.labCancel.setText("Loading Photos..."+str(i))
+                        self.labCancel.repaint()
+                        self.listPhotos.repaint()
+                except:
+                        continue
+                        
+                i+=1
+                if i == self.val.thumbsCount:
+                    self.listPhotos.addItem("Load More...")
+                    break
+                    
+            self.listPhotos.repaint()
+            self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            #    221
+                
+#         icon2.addPixmap(im,  QtGui.QIcon.Normal, QtGui.QIcon.Off)
+#         icon = QIcon(QPixmap.fromImage(ImageQt.ImageQt(im)))
+#			item = QListWidgetItem(os.path.basename(url)[:20] + "...", self.pictureListWidget)
+#			item.setStatusTip(url)
+#			item.setIcon(icon)
+            
+            
+#            Imitem = QtGui.QListWidgetItem(file.replace(".jpg", "")), self.listPhotos);
+#            Imitem.setIcon(QtGui.QIcon(im))
+#            self.listPhotos.addItem(Imitem)
+
+            
+            #im.save(file + ".thumbnail", "JPEG")
+            #elf.val.curIm = Image.open(filename)
+
+#            p = open(filename, "rb")
+#            tags = EXIF.process_file(p)
+#            self.listEXIFData.addItem
+
+        
     @pyqtSignature("int")
     def on_cSlide_Hi_valueChanged(self, value):
         """
@@ -621,13 +706,14 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         Slot documentation goes here.
         """
         
-        #out = im.transpose(Image.FLIP_LEFT_RIGHT)
-        #out = im.transpose(Image.FLIP_TOP_BOTTOM)
-        #out = im.transpose(Image.ROTATE_90)
-        #out = im.transpose(Image.ROTATE_180)
-        #out = im.transpose(Image.ROTATE_270)
-
-    
+#     out = im.transpose(Image.FLIP_LEFT_RIGHT)
+#     out = im.transpose(Image.FLIP_TOP_BOTTOM)
+#     out = im.transpose(Image.ROTATE_90)
+#     out = im.transpose(Image.ROTATE_180)
+#     out = im.transpose(Image.ROTATE_270)
+#     out
+#    
+#    
     @pyqtSignature("")
     def on_btn_rot_180_released(self):
         """
@@ -639,29 +725,27 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btnFullScreen_released(self):
         """
-        Slot documentation goes here.
+        utton handler for fullscreen  open, calls FullScreenToggle
         """
         self.FullScreenToggle(True)
     
     @pyqtSignature("")
     def on_btnFullScreenClose_released(self):
         """
-        Slot documentation goes here.
+        Button handler for fullscreen  close, calls FullScreenToggle
         """
         self.FullScreenToggle(False)
 
     @pyqtSignature("")
-    def FullScreenToggle(self,  Show):
+    def FullScreenToggle(self,  Show,  ForceTab=0):
         """
         Slot documentation goes here.
         """
         if (Show):
-            self.tabPhoto.setCurrentIndex(0)
+            self.tabPhoto.setCurrentIndex(ForceTab)
             self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
-            #self.tabStrip.setGeometry(QtCore.QRect(190, 120, 691, 491))
         else:
             self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            #self.tabStrip.setGeometry(QtCore.QRect(190, 40, 691, 491))
             self.photo.repaint()
             self.photo_Orig.repaint()
             
@@ -672,7 +756,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_BC_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Blue-Cyan
         """
         self.val.valBW = "BC"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -680,7 +764,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_GC_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Green-Cyan
         """
         self.val.valBW = "GC"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -688,7 +772,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_GY_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Green-Yellow
         """
         self.val.valBW = "GY"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -696,7 +780,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_BM_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Blue-Magenta
         """
         self.val.valBW = "BM"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -704,7 +788,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_RM_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Red-Magenta
         """
         self.val.valBW = "RM"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -712,7 +796,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btn_RY_released(self):
         """
-        Slot documentation goes here.
+        Black and white conversion to Red-yellow
         """
         self.val.valBW = "RY"
         self.BWApply(self.val.curThumb,  self.val.valBW,  False)
@@ -769,12 +853,114 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btnBug_released(self):
         """
-        Slot documentation goes here.
+        Submit bug report to bugs.maemo.org
         """
  
         webbrowser.open("https://bugs.maemo.org/enter_bug.cgi?product=AnselA")
-        
-        
+#        self.btnBug.anim=QtCore.QPropertyAnimation(self.btnBug.proxy, "opacity")
+#        self.btnBug.anim.setDuration(200)
+#        self.btnBug.anim.setStartValue(self.btnBug.proxy.opacity())
+#        self.btnBug.anim.setEndValue(target)
+#        self.btnBug.anim.start()
+#        self.btnBug.anim.finished.connect(self.btnBug.anim.deleteLater)
+#    
+#        self.btnBug.anim.finished.connect(self.btnBug)
     
-
+    @pyqtSignature("")
+    def on_btnPListCancel_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        self.val.populatePhotoList = False
+    
+    def LoadCurImageFromPhotoBrowser(self):
+        self.ToggleThumbWait(True)
+        self.FullScreenToggle(False)
+        self.repaint()
+        self.ImageOpen(self.val.plistIm)
+        self.ImageDisplayRefresh(True)
         
+    @pyqtSignature("")
+    def on_btnPlistZoom_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.LoadCurImageFromPhotoBrowser()
+
+
+    def ToggleThumbWait(self,  Show):
+        if Show:
+            self.labWaitThumb.setGeometry(QtCore.QRect(30, 120, 251, 161))
+#            self.movie = QtGui.QMovie("ui/resources/wait.png")
+#
+#            self.labWaitThumb.setMovie(self.movie)
+#        
+#            self.movie.setCacheMode(QtGui.QMovie.CacheAll)
+#            self.movie.setSpeed(100) 
+#            self.movie.start()
+        else:
+            self.labWaitThumb.setGeometry(QtCore.QRect(30, 120, 0, 0))
+    
+    @pyqtSignature("QListWidgetItem*")
+    def on_listPhotos_itemClicked(self, item):
+        """
+        Slot documentation goes here.
+        """
+        if str(item.text()) == "Load More...":
+            self.val.thumbsCount +=100
+            self.populatePhotoList()
+        else:
+            self.labWait_2.setGeometry(QtCore.QRect(200, 40, 421, 251))
+            self.labWait_2.repaint()
+            self.val.plistIm= self.val.imageDir+str(item.text())+".jpg"
+            im = Image.open(self.val.plistIm)
+            self.photoListZoom.setPixmap(Core.pil2qpixmap(im))
+            self.labWait_2.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            self.labWait_2.repaint()
+    
+    @pyqtSignature("")
+    def on_butReturn_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.FullScreenToggle(False)
+    
+    
+    @pyqtSignature("QListWidgetItem*")
+    def on_listPhotos_itemDoubleClicked(self, item):
+        """
+        Slot documentation goes here.
+        """
+        self.LoadCurImageFromPhotoBrowser()
+    
+    @pyqtSignature("")
+    def on_btnReloadPList_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 791, 441))
+    
+    @pyqtSignature("")
+    def on_btnReloadCancel_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
+    
+    @pyqtSignature("")
+    def on_btnReloadGo_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        self.populatePhotoList(True)
+    
+    @pyqtSignature("")
+    def on_btnPhotoBrowser_released(self):
+        """
+        Slot documentation goes here.
+        """
+        self.FullScreenToggle(True,  2)
+        self.populatePhotoList()
+    
